Skip to contents

Searches the replication registry for papers matching a keyword in the title, handle, or author fields.

Usage

search_papers(query)

Arguments

query

Character string used to search paper titles, handles, or authors.

Value

A filtered data frame of matching papers.

Examples

if (FALSE) { # \dontrun{
search_papers("insurgency")
search_papers("Blair")
search_papers("Acemoglu")
search_papers("Fearon")
search_papers("S0003055403000534")
search_papers("rep-template")
} # }