Render code lines with clickable file links for Shiny
Source:R/code_links.R
render_code_html_with_links.RdRender code lines with clickable file links for Shiny
Usage
render_code_html_with_links(
lines,
language = c("stata", "r"),
study_root,
source_path = NULL,
globals = NULL
)